/*   JavaScript code for Falcons Football Schedule Widget.
 *   Copyright (C) 2005 Marc Oburg <moburg@yahoo.com>
 *   Displays the 2005 Falcons football schedule.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 *  USA
 */


 /////////////////////////////////////////////////////////////////////////////////
 // FileName: fetchData.js
 // Description: updates the schedule grid.  also contains many other javascript
 //              functions for cleaning and displaying data
 /////////////////////////////////////////////////////////////////////////////////
   function updateTimestamp() 
   {
      var temp = Date().split(' ');
      var lastUpdate = temp[0] + ' ' + temp[1]+' ' +temp[2]+' ' +temp[3] +' ' + temp[4];

      return lastUpdate.data="Last updated: " + lastUpdate
   }

   function trimString (str) 
   {
      try
      {
         return str.replace(/^\s+/g, '').replace(/\s+$/g, '');
      }
      catch(e)
      {
         return "";
      }
   }

   function cleanString (str) 
   {
      //replace multiple whitespaces with one
      //removes javascript comments and other html tags

      try
      {
         return str.replace(/<[^<]*>/g, '').replace(/^\s+/g, '').replace(/\s+$/g, '');
      }
      catch(e)
      {
         return "";
      }
   }

   function removeNBSP (str)
   {
      try
      {
         return str.replace(/&nbsp;/gi, ' ');
      }
      catch(e)
      {
         return "";
      }
   }

   function loadPreferences()
   {
      display[0] = preferences.showWeek.value;
      display[1] = preferences.showDate.value;
      display[2] = "1";
      display[3] = preferences.showTimeTVScore.value;
   }

   function deleteAll(array)
   {
      for (item in array)
         delete array[item];
   }

   function fetchData() 
   {
      loadPreferences();

      deleteAll(backgroundImages);
      deleteAll(games);

      var imgSrc = "Resources/images"

      title.data  = "Falcons " + preferences.year.value + " Football Schedule";
      title.font  = preferences.titleFont.value;
      title.size  = preferences.titleSize.value;
      title.color = preferences.titleColor.value;

      var logoHeightVar = logo.height-20;

      var backgroundOffset = logo.vOffset + logoHeightVar/2;

      plusMinus.hOffset = logo.hOffset + logo.width-20;
      title.hOffset = plusMinus.hOffset + plusMinus.width + 3;
      backgroundOffset = logo.vOffset+ logoHeightVar+3;

      logo.opacity=parseInt(preferences.logoOpacity.value);

      title.vOffset = logo.vOffset+ logoHeightVar;
      if (preferences.showTitle.value=="0")
         title.opacity=0;
      else
         title.opacity=255;

      // Build URL to fetch data
      theURL="http://sports-att.espn.go.com/nfl/teams/schedule?team=atl&year=" + preferences.year.value;

      var urlData;
      var url = new URL();
      urldata = url.fetch(theURL);

      //initialize header row if the user wants to see it
      var count=0;

      if (preferences.showHeaderRow.value=="1")
      {
         games[count] = new Array();

         backgroundImages[count]= new Image();
         backgroundImages[count].vOffset = backgroundOffset;
         backgroundImages[count].opacity = parseInt(preferences.bgOpacity.value);
         backgroundImages[count].hOffset = defaultRowHOffset;
         backgroundImages[count].src =imgSrc + "/rowMiddle.png";

         if (preferences.colorizeHeaderRow.value=="1")
            backgroundImages[count].colorize= preferences.headerRowColor.value;
         else
            backgroundImages[count].colorize= "";

         for (var i=0; i < display.length; i++)
         {
            if (display[i]=="1")
            {
               games[count][i] = new Text();
               games[count][i].font  = preferences.headerTextFont.value;
               games[count][i].size  = preferences.headerTextSize.value;
               games[count][i].color = preferences.headerTextColor.value;
               games[count][i].alignment = "left";
               games[count][i].bgColor = "#000000";
               games[count][i].hOffset=0;
               games[count][i].opacity = 255;
            }
         }

         if (display[0]=="1")
            games[count][0].data = "Week";

         if (display[1]=="1")
            games[count][1].data = "Day/Date";

         if (display[2]=="1")
            games[count][2].data = "Opponent";

         if (display[3]=="1")
            games[count][3].data = "Outcome/Time";

         var tallest = games[count][2].height;

         for (var i=0; i < display.length; i++)
         {
            if (display[i]=="1")
               widest[i] = games[count][i].width;
         }

         backgroundImages[count].height  = tallest+padding;

         for (var i=0; i < display.length; i++)
         {
            if (games[count][i]!=null)
               games[count][i].vOffset = backgroundImages[count].vOffset + tallest;
         }

         backgroundOffset = backgroundImages[count].vOffset  + backgroundImages[count].height;

         count++;
      }   // end if display header row
      else
      {
         for (var i=0; i < display.length; i++)
            widest[i]=0;
      }

   //                  <tr class=evenrow valign=top>
   // var regexRow  = /<tr class=\w{3,4}row valign=top/>([.\s\S]*?)(<\/tr>)/gim;

      var regexRow  = /<tr[^<>]*>([.\s\S]*?)<\/tr>/gim;
      var regexCell = /<td[^<>]*>([.\s\S]*?)<\/td>/gim;

      var week = 1;
      var date;
      var who;
      var results;

      var gamePlayed = true;
      var goodRow = true;

      while ( rows = regexRow.exec( urldata ) )
      {
         //alert ( rows[1] );
         var cc = 0;

         myWhile:
         while ( cells = regexCell.exec( rows[1] ) )
         {
            //alert ( cells[1] );
            var cellData = cleanString(removeNBSP( cells[1] ));

            //alert ( cellData );
            mySwitch:
            switch (cc)
            {
               case 0:  //week
                  if ( cellData == week )
                     goodRow = true;
                  else
                     goodRow = false;
                  //alert ( week + " - " + cellData + " - " + goodRow );                  
                  break;

               case 1:  //date
                   date = cellData;
                   if ( cellData == "BYE WEEK" )
                   {
                      who = " ";
                      results = " ";
                   }
                   break;

               case 2:  //who
                   who = cellData;
                   break;

               case 3:  //column 4 (results or tickets)
                   results = cellData;
                   if ( (results.substring( 0, 1 ) == "W" ) || 
                        (results.substring( 0, 1 ) == "L" ) )
                   {
                      gamePlayed = true;   
                   }
                   else
                   {
                      gamePlayed = false;    
                   }
                   break;

               case 4:  //results or TV
                   if (gamePlayed == false)
                      results = " (" + cellData + ")";
                   break;

               case 5:  //results or Time
                   if (gamePlayed == false)
                      results = cellData + results;
                   break;

               case 6:  //stats, not displayed
                   break;

               case 7:  //stats, not displayed
                   break;

               case 7:  //stats, not displayed
                   break;

               default:
            } //end switch
              cc++;
         } //end while cells

         if ( goodRow )
         {
            var homeGame = who.indexOf('at ') > -1 ? false: true;

            // Draw Background Rows
            games[count] = new Array();
            displayCount=0;

            backgroundImages[count] = new Image();
            backgroundImages[count].vOffset = backgroundOffset;
            backgroundImages[count].opacity = parseInt(preferences.bgOpacity.value);
            backgroundImages[count].hOffset = defaultRowHOffset;
            backgroundImages[count].src = imgSrc + "/rowMiddle.png";

            if (preferences.colorizeRows.value=="1")
               backgroundImages[count].colorize= preferences.rowColor.value;
            else
               backgroundImages[count].colorize= "";
            
            for (var i=0; i < display.length; i++)
            {
               if (display[i]=="1")
               {
                  games[count][i] = new Text();
                  games[count][i].width = -1; //width is dynamic
                  games[count][i].vOffset = 0;
                  games[count][i].hOffset = defaultRowHOffset;
                  games[count][i].bgColor = "#000000";
                  games[count][i].alignment = "left";
                  games[count][i].opacity = 255;

                  games[count][i].font = preferences.textFont.value;
                  games[count][i].size = preferences.textSize.value;

                  if (homeGame)
                     games[count][i].color = preferences.homeTextColor.value;
                  else
                     games[count][i].color = preferences.awayTextColor.value;
 
                  displayCount++;
               } // if (display[i]=="1")
            } // for i = 0 to display.length

            //write the week
            if (display[0]=="1")
            {
               games[count][0].data = "         " + week;
               games[count][0].alignment = "center";
            }

            //write the date
            if (display[1]=="1")
               games[count][1].data = date;

            //write the who
            if (display[2]=="1")
               games[count][2].data = who;

            //write the results/time
            if (display[3]=="1")
               games[count][3].data = results;

            tallest = games[count][2].height;
            for (var i=0; i < display.length; i++)
            {
               if (display[i]=="1")
               {
                  if (games[count][i].width > widest[i])
                     widest[i] = games[count][i].width;
               }
            }

            backgroundImages[count].height = tallest+padding;

            for (var i=0; i < display.length; i++)
            {
               if (games[count][i]!=null)
                  games[count][i].vOffset = backgroundImages[count].vOffset + tallest;
            }
            backgroundOffset += backgroundImages[count].height;
            count++;
            week++;
         } //good column count (i.e. we want to disply this row)
      } //row regex loop

      //loop thru and fix the offsets and set the image widths

      for (var i=0; i < count; i++)
      {
         for (var j=0; j < display.length; j++)
         {
            if (display[j]=="1")
            {
               var offset = defaultRowHOffset;
               for (var k=0; k < j; k++)
               {
                  if (display[k]=="1" && widest[k] >0 )
                     offset += widest[k]+hCellSpacing;
               } //for k lt j

               games[i][j].hOffset = padding + offset;
            } //if
         } //for

         var maxWidth=0;
         var dispCount=0;
         for (var w=0; w < widest.length; w++)
         {
            if (display[w] > 0)
            {
               dispCount++;
               maxWidth += widest[w];
            }
         }
         backgroundImages[i].width = hCellSpacing + maxWidth + ((dispCount-1)*hCellSpacing);
      } //for

      count--;

      mainWindow.width = backgroundImages[count].hOffset + backgroundImages[count].width;
      mainWindow.height = backgroundImages[count].vOffset + backgroundImages[count].height + 10;

      loadingImg.opacity=0;
      loadingTxt.opacity=0;

      logo.tooltip = updateTimestamp();
      showOrHideMe();
   }

   function showOrHideMe() {
      var imageOpacity = preferences.isMaximized.value=="0" ? 0 : parseInt(preferences.bgOpacity.value);
      var gameTextOpacity =  preferences.isMaximized.value=="0" ? 0 : 255;
      var titleOpacity= preferences.isMaximized.value=="0" || preferences.showTitle.value=="0" ? 0 : 255;

      if (preferences.isMaximized.value=="0")
         plusMinus.src = "Resources/images/plus.png"
      else
         plusMinus.src = "Resources/images/minus.png"

      for (var i = 0; i< backgroundImages.length; i++) {
         if (backgroundImages[i] != null) {
            backgroundImages[i].opacity = imageOpacity;
         }
      }

      for (var i=0 ; i < games.length; i++) {
         if (games[i] != null ) {
            for (var j=0; j < games[i].length; j++) {
               if (games[i][j] != null)
                  games[i][j].opacity=gameTextOpacity;
            }
         }
      }

      title.opacity=titleOpacity;
   }
